/// @file openLayers4.js
/// @author Mario Chirinos Colunga
/// @date 2016-04-14
/// 

//------------------------------------------------------------------------------
/**
 * Definitions for the languages.
 * @param  divID div name to insert the map
 * @param  lng Longitude
 * @param  lat Latitude
 * @param  z Zoom
 * @return OpenStreetMapsClass object
 */
function OpenStreetMapsClass(divID, lng, lat, z)
{
	//this.vectorLayers = [];
	var self=this;
	this.vectorLayer = new ol.layer.Vector({source: new ol.source.Vector({features: []})});
	this.map = new ol.Map({
				layers: [new ol.layer.Tile({
							//source: new ol.source.OSM()
							source: new ol.source.XYZ({url:'https://api.tiles.mapbox.com/v4/mapbox.light/{z}/{x}/{y}.png?access_token=pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpejY4NXVycTA2emYycXBndHRqcmZ3N3gifQ.rJcFIG214AriISLbB6B5aw'})

							}),this.vectorLayer],
				target: 'map',
				controls: ol.control.defaults({attributionOptions: ({collapsible: true})}),
				view: new ol.View({ center: ol.proj.fromLonLat([lng,lat]),  zoom: z})
				});

	this.map.on('click', function(e) {self.onMapClick(e)});

	this.map.on("pointermove", function (e)
	{
		var hit = this.forEachFeatureAtPixel(e.pixel, function(feature, layer) {return true;}); 
		if (hit)
			this.getTargetElement().style.cursor = 'pointer';
		else
			this.getTargetElement().style.cursor = '';
	});
};
//------------------------------------------------------------------------------
OpenStreetMapsClass.prototype.onMapClick = function(e)
{
	console.log("onMapClick");
	var feature = this.map.forEachFeatureAtPixel(e.pixel,function(feature) {return feature;});
	if(feature && feature.onClick!==undefined)
		feature.onClick(e);
}
//------------------------------------------------------------------------------

/**
 *	Browser Geolocation
 */
OpenStreetMapsClass.prototype.geolocation = function()
{
	var self = this;
	var geoOptions = {
				enableHighAccuracy: true,
				timeout: 5000,
				maximumAge: 0
			};
	if (navigator.geolocation)
	{
		navigator.geolocation.getCurrentPosition(function(position){
									console.log("navigator geolocation:"+position.coords.longitude +","+ position.coords.latitude);
									self.map.getView().setCenter( ol.proj.fromLonLat([position.coords.longitude, position.coords.latitude]));
											

									},
							function(error) {
									console.log("ERROR "+error.code+": navigator geolocation");

									},

								geoOptions);
	}
	else
	{
		console.log("NO navigator geolocation");
	}
}
//------------------------------------------------------------------------------
/**
 *	@param lng Longitude
 *	@param lat Latitude
 *	@pram style ol.style.Style
 *	@return feature added
 */
OpenStreetMapsClass.prototype.addFeatureToVectorLayer = function(lng,lat,style,jsonObj)
{

	var iconFeature = new ol.Feature({
					geometry: new ol.geom.Point(ol.proj.fromLonLat([lng,lat])), json: jsonObj
				});
   	iconFeature.setStyle(style);
	//iconFeature.on("click", function(e){console.log("click")}, this);

	this.vectorLayer.getSource().addFeature(iconFeature);

	return iconFeature;

}
//------------------------------------------------------------------------------
/**
 *	@param	url icon file location
 *	@param	x offset X [0..1] relative to icon width
 *	@param	y offset Y [0..1] relative to icon height
 */
OpenStreetMapsClass.prototype.iconStyle = function(url,x,y)
{
	return new ol.style.Style({
		image: new ol.style.Icon( ({
		  anchor: [x, y],
		  anchorXUnits: 'fraction',
		  anchorYUnits: 'fraction',
		  src: url
		}))
	      });

}

